@@ -404,6 +404,11 @@ class IBool(IField):
         description=_("""The field default value may be None or a legal
                         field value""")
         )
+    required = Bool(
+        title=_("Required"),
+        description=(_("Tells whether a field requires its value to exist.")),
+        required=False,
+        default=False)
 
 
 class IBytes(IMinMaxLen, IIterable, IField):
@@ -463,7 +468,8 @@ class INativeStringLine(ITextLine if PY3 else IBytesLine):
 
 
 class IPassword(ITextLine):
-    "Field containing a unicode string without newlines that is a password."
+    """Field containing a unicode password string without newlines."""
+
 
 ###
 # Numbers
@@ -550,6 +556,7 @@ class IReal(IComplex):
                         field value""")
         )
 
+
 class IRational(IReal):
     """
     Field containing a rational number: :class:`numbers.IRational`.
@@ -576,6 +583,7 @@ class IRational(IReal):
                         field value""")
         )
 
+
 class IIntegral(IRational):
     """
     Field containing an integral number: class:`numbers.Integral`.
@@ -600,6 +608,8 @@ class IIntegral(IRational):
         description=_("""The field default value may be None or a legal
                         field value""")
         )
+
+
 ##
 # Concrete numbers
 ##
@@ -667,6 +677,7 @@ class IDecimal(INumber):
 # End numbers
 ###
 
+
 class IDatetime(IMinMax, IField):
     """Field containing a datetime."""
 
@@ -757,6 +768,7 @@ class IChoice(IField):
         default=None
         )
 
+
 # Collections:
 
 # Abstract
@@ -792,6 +804,7 @@ class IMutableSequence(ISequence):
     .. versionadded:: 4.6.0
     """
 
+
 class IUnorderedCollection(ICollection):
     """Abstract interface specifying that the value cannot be ordered"""
 
@@ -799,14 +812,16 @@ class IUnorderedCollection(ICollection):
 class IAbstractSet(IUnorderedCollection):
     """An unordered collection of unique values."""
 
-    unique = Bool(description="This ICollection interface attribute must be True")
+    unique = Bool(
+        description="This ICollection interface attribute must be True")
 
 
 class IAbstractBag(IUnorderedCollection):
     """An unordered collection of values, with no limitations on whether
     members are unique"""
 
-    unique = Bool(description="This ICollection interface attribute must be False")
+    unique = Bool(
+        description="This ICollection interface attribute must be False")
 
 
 # Concrete
@@ -844,18 +859,19 @@ class IObject(IField):
 
     schema = Object(
         IInterface,
-        description=_("The Interface that defines the Fields comprising the Object.")
+        description=_("The Interface that defines the Fields comprising the "
+                      "Object.")
     )
 
     validate_invariants = Bool(
         title=_("Validate Invariants"),
-        description=_("A boolean that says whether ``schema.validateInvariants`` "
-                      "is called from ``self.validate()``. The default is true."),
+        description=_("A boolean that says whether "
+                      "``schema.validateInvariants`` is called from "
+                      "``self.validate()``. The default is true."),
         default=True,
     )
 
 
-
 class IMapping(IMinMaxLen, IIterable, IContainer):
     """
     Field containing an instance of :class:`collections.Mapping`.
@@ -866,7 +882,8 @@ class IMapping(IMinMaxLen, IIterable, IContainer):
     """
     key_type = Object(
         IField,
-        description=_("Field keys must conform to the given type, expressed via a Field.")
+        description=_("Field keys must conform to the given type, expressed "
+                      "via a Field.")
     )
 
     value_type = Object(
