@@ -17,8 +17,10 @@ import unittest
 import unicodedata
 
 # pylint:disable=protected-access,inherit-non-class,blacklisted-name
+# pylint:disable=attribute-defined-outside-init
 
-class EqualityTestsMixin(object):
+
+class InterfaceConformanceTestsMixin(object):
 
     def _getTargetClass(self):
         raise NotImplementedError
@@ -54,6 +56,28 @@ class EqualityTestsMixin(object):
             verifyObject(iface, instance)
         return verifyObject
 
+    def test_iface_is_first_in_sro(self):
+        from zope.interface import implementedBy
+        implemented = implementedBy(self._getTargetClass())
+        __traceback_info__ = implemented.__sro__
+        self.assertIs(implemented, implemented.__sro__[0])
+        self.assertIs(self._getTargetInterface(), implemented.__sro__[1])
+
+    def test_implements_consistent__sro__(self):
+        from zope.interface import ro
+        from zope.interface import implementedBy
+        __traceback_info__ = implementedBy(self._getTargetClass()).__sro__
+        self.assertTrue(
+            ro.is_consistent(implementedBy(self._getTargetClass())))
+
+    def test_iface_consistent_ro(self):
+        from zope.interface import ro
+        __traceback_info__ = self._getTargetInterface().__iro__
+        self.assertTrue(ro.is_consistent(self._getTargetInterface()))
+
+
+class EqualityTestsMixin(InterfaceConformanceTestsMixin):
+
     def test_is_hashable(self):
         field = self._makeOne()
         hash(field)  # doesn't raise
@@ -223,7 +247,8 @@ class LenTestsMixin(object):
 
 class WrongTypeTestsMixin(object):
 
-    def assertRaisesWrongType(self, field_or_meth, expected_type, *args, **kwargs):
+    def assertRaisesWrongType(self, field_or_meth, expected_type,
+                              *args, **kwargs):
         from zope.schema.interfaces import WrongType
         field = None
         with self.assertRaises(WrongType) as exc:
@@ -244,7 +269,6 @@ class WrongTypeTestsMixin(object):
             # A single keyword argument
             self.assertIs(ex.value, kwargs.popitem()[1])
 
-
     def assertAllRaiseWrongType(self, field, expected_type, *values):
         for value in values:
             __traceback_info__ = value
@@ -659,7 +683,7 @@ class FieldTests(EqualityTestsMixin,
     def test_validate_missing_not_required(self):
         missing = object()
 
-        field = self._makeOne(
+        field = self._makeOne(  # pragma: no branch
             required=False, missing_value=missing, constraint=lambda x: False,
         )
         self.assertEqual(field.validate(missing), None)  # doesn't raise
@@ -668,14 +692,16 @@ class FieldTests(EqualityTestsMixin,
         from zope.schema._bootstrapinterfaces import RequiredMissing
         missing = object()
 
-        field = self._makeOne(
+        field = self._makeOne(  # pragma: no branch
             required=True, missing_value=missing, constraint=lambda x: False,
         )
         self.assertRaises(RequiredMissing, field.validate, missing)
 
     def test_validate_wrong_type(self):
 
-        field = self._makeOne(required=True, constraint=lambda x: False)
+        field = self._makeOne(  # pragma: no branch
+            required=True, constraint=lambda x: False,
+        )
         field._type = str
         self.assertRaisesWrongType(field, str, 1)
 
@@ -965,7 +991,8 @@ class TextTests(EqualityTestsMixin,
         self.assertEqual(txt.fromUnicode(deadbeef), deadbeef)
 
     def test_normalization(self):
-        deadbeef = unicodedata.normalize('NFD', b'\xc3\x84\xc3\x96\xc3\x9c'.decode('utf-8'))
+        deadbeef = unicodedata.normalize(
+            'NFD', b'\xc3\x84\xc3\x96\xc3\x9c'.decode('utf-8'))
         txt = self._makeOne()
         self.assertEqual(txt.unicode_normalization, 'NFC')
         self.assertEqual(
@@ -995,6 +1022,7 @@ class TextTests(EqualityTestsMixin,
         # see https://github.com/zopefoundation/zope.schema/issues/90
         import pickle
         orig_makeOne = self._makeOne
+
         def makeOne(**kwargs):
             result = orig_makeOne(**kwargs)
             if not kwargs:
@@ -1122,6 +1150,7 @@ class PasswordTests(EqualityTestsMixin,
 
 
 class BoolTests(EqualityTestsMixin,
+                WrongTypeTestsMixin,
                 unittest.TestCase):
 
     def _getTargetClass(self):
@@ -1136,11 +1165,20 @@ class BoolTests(EqualityTestsMixin,
         txt = self._makeOne()
         self.assertEqual(txt._type, bool)
 
+    def test_validate_wrong_type(self):
+        boo = self._makeOne()
+        self.assertRaisesWrongType(boo, boo._type, '')
+
     def test__validate_w_int(self):
         boo = self._makeOne()
         boo._validate(0)  # doesn't raise
         boo._validate(1)  # doesn't raise
 
+    def test__validate_w_bool(self):
+        boo = self._makeOne()
+        boo._validate(False)  # doesn't raise
+        boo._validate(True)   # doesn't raise
+
     def test_set_w_int(self):
         boo = self._makeOne(__name__='boo')
         inst = DummyInst()
@@ -1149,6 +1187,14 @@ class BoolTests(EqualityTestsMixin,
         boo.set(inst, 1)
         self.assertEqual(inst.boo, True)
 
+    def test_set_w_bool(self):
+        boo = self._makeOne(__name__='boo')
+        inst = DummyInst()
+        boo.set(inst, False)
+        self.assertEqual(inst.boo, False)
+        boo.set(inst, True)
+        self.assertEqual(inst.boo, True)
+
     def test_fromUnicode_miss(self):
 
         txt = self._makeOne()
@@ -1188,7 +1234,8 @@ class NumberTests(EqualityTestsMixin,
     def test_instance_conforms_to_iface(self):
         from zope.schema._bootstrapinterfaces import IFromUnicode
         from zope.schema._bootstrapinterfaces import IFromBytes
-        verifyObject = super(NumberTests, self).test_instance_conforms_to_iface()
+        verifyObject = (
+            super(NumberTests, self).test_instance_conforms_to_iface())
         verifyObject(IFromUnicode, self._makeOne())
         verifyObject(IFromBytes, self._makeOne())
 
@@ -1203,6 +1250,7 @@ class ComplexTests(NumberTests):
         from zope.schema.interfaces import IComplex
         return IComplex
 
+
 class RealTests(WrongTypeTestsMixin,
                 NumberTests):
 
@@ -1217,8 +1265,10 @@ class RealTests(WrongTypeTestsMixin,
     def test_ctor_real_min_max(self):
         from fractions import Fraction
 
-        self.assertRaisesWrongType(self._makeOne, self._getTargetClass()._type, min='')
-        self.assertRaisesWrongType(self._makeOne, self._getTargetClass()._type, max='')
+        self.assertRaisesWrongType(
+            self._makeOne, self._getTargetClass()._type, min='')
+        self.assertRaisesWrongType(
+            self._makeOne, self._getTargetClass()._type, max='')
 
         field = self._makeOne(min=Fraction(1, 2), max=2)
         field.validate(1.0)
@@ -1373,7 +1423,8 @@ class ObjectTests(EqualityTestsMixin,
     def _makeOneFromClass(self, cls, schema=None, *args, **kw):
         if schema is None:
             schema = self._makeSchema()
-        return super(ObjectTests, self)._makeOneFromClass(cls, schema, *args, **kw)
+        return super(ObjectTests, self)._makeOneFromClass(
+            cls, schema, *args, **kw)
 
     def _makeSchema(self, **kw):
         from zope.interface import Interface
@@ -1728,13 +1779,12 @@ class ObjectTests(EqualityTestsMixin,
                     raise Invalid("Bar is not valid")
 
         @implementer(ISchema)
-        class O(object):
+        class Obj(object):
             foo = u''
             bar = b''
 
-
         field = self._makeOne(ISchema)
-        inst = O()
+        inst = Obj()
 
         # Fine at first
         field.validate(inst)
@@ -1786,7 +1836,6 @@ class ObjectTests(EqualityTestsMixin,
         class ValueType(object):
             "The value type"
 
-
         field.validate(ValueType())
 
     def test_bound_field_of_collection_with_choice(self):
@@ -1802,7 +1851,6 @@ class ObjectTests(EqualityTestsMixin,
         from zope.schema.interfaces import SchemaNotCorrectlyImplemented
         from zope.schema.vocabulary import SimpleVocabulary
 
-
         @implementer(IContextSourceBinder)
         class EnumContext(object):
             def __call__(self, context):
@@ -1811,7 +1859,8 @@ class ObjectTests(EqualityTestsMixin,
         class IMultipleChoice(Interface):
             choices = Set(value_type=Choice(source=EnumContext()))
             # Provide a regular attribute to prove that binding doesn't
-            # choke. NOTE: We don't actually verify the existence of this attribute.
+            # choke. NOTE: We don't actually verify the existence of this
+            # attribute.
             non_field = Attribute("An attribute")
 
         @implementer(IMultipleChoice)
@@ -1822,14 +1871,13 @@ class ObjectTests(EqualityTestsMixin,
 
             def __iter__(self):
                 # EnumContext calls this to make the vocabulary.
-                # Fields of the schema of the IObject are bound to the value being
-                # validated.
+                # Fields of the schema of the IObject are bound to the value
+                # being validated.
                 return iter(range(5))
 
         class IFavorites(Interface):
             fav = Object(title=u"Favorites number", schema=IMultipleChoice)
 
-
         @implementer(IFavorites)
         class Favorites(object):
             fav = FieldProperty(IFavorites['fav'])
@@ -1893,7 +1941,7 @@ class DummyInst(object):
         self._exc = exc
 
     def validate(self, value):
-        if self._exc is not None:
+        if self._exc is not None:  # pragma: no branch
             raise self._exc()
 
 
@@ -1903,6 +1951,6 @@ def test_suite():
     suite = unittest.defaultTestLoader.loadTestsFromName(__name__)
     suite.addTests(doctest.DocTestSuite(
         zope.schema._bootstrapfields,
-        optionflags=doctest.ELLIPSIS|IGNORE_EXCEPTION_MODULE_IN_PYTHON2
+        optionflags=doctest.ELLIPSIS | IGNORE_EXCEPTION_MODULE_IN_PYTHON2
     ))
     return suite
